@@ -14,6 +14,7 @@ import pickle
 from itertools import combinations
 import shutil
 import math
+import re
 import psutil
 import platform
 import glob
@@ -26,6 +27,8 @@ import subprocess
 import pkg_resources
 from enum import Enum
 
+import wizzi_utils
+
 LINES = '-' * 80
 NOT_FOUND = '{} Not found'
 CREATED = '{} Created'
@@ -258,11 +261,34 @@ def get_cudnn_version(cudnn_path: str) -> str:
                 ls_spl = ls.split(' ')
                 if len(ls_spl) == 3:
                     pa = ls_spl[2]
+        f_obj.close()
         if ma and mi and pa:
             cudnn_v = '{}.{}.{}'.format(ma, mi, pa)
     return cudnn_v
 
 
+def extract_cuda_version_linux(cuda_path: str) -> str:
+    cuda_v = None
+
+    if os.path.isfile('{}/version.txt'.format(cuda_path)):
+        cuda_v_file = '{}/version.txt'.format(cuda_path)
+        f_obj = open(cuda_v_file, 'r')
+        for line in f_obj:
+            ls = line.strip()
+            if ls.startswith('CUDA Version'):
+                ls_spl = ls.split(' ')
+                if len(ls_spl) == 3:
+                    cuda_v = line.strip().split(' ')[2]
+                    break
+    elif os.path.isfile('{}/version.json'.format(cuda_path)):
+        import json
+        cuda_v_file = '{}/version.json'.format(cuda_path)
+        j_obj = json.load(fp=open(cuda_v_file))
+        cuda_v = j_obj['cuda']['version']
+
+    return cuda_v
+
+
 def get_cuda_version(ack: bool = False, tabs: int = 1) -> str:
     """
     :param ack:
@@ -270,46 +296,82 @@ def get_cuda_version(ack: bool = False, tabs: int = 1) -> str:
     :return: cuda version if found on environment variables
     see get_cuda_version_test()
     """
-    cuda_v = None
-    cudnn_v = None
+    cuda_str = add_color('* No CUDA found', ops=FAIL_C)
+    try:
+        cuda_path, cuda_v, cudnn_v = None, None, None
+        if is_windows():
+            # e.g. C:\Program Files\NVIDIA GPU Computing Toolkit\CUDA\v10.2
+            cuda_path = get_env_variable(key='CUDA_PATH')
+            if cuda_path is not None and os.path.isdir(cuda_path):
+                cuda_v = os.path.basename(cuda_path)  # version taken from dir name
+                cudnn_path = '{}/include/cudnn_version.h'.format(cuda_path)
+                if os.path.isfile(cudnn_path):
+                    cudnn_v = get_cudnn_version(cudnn_path=cudnn_path)
 
-    if is_windows():
-        cuda_path = get_env_variable(key='CUDA_PATH')
-        if cuda_path is not None:
-            cuda_v = os.path.basename(cuda_path)
+        elif is_linux():
+            # try to locate cuda version file
+            known_options = [
+                '/usr/local/cuda',
+            ]
+
+            # e.g. /usr/local/cuda-11.7 or /usr/local/cuda
+            cuda_path = get_env_variable(key='CUDA_ROOT')  # first try with env variable
+            if cuda_path is None or not os.path.isdir(cuda_path):
+                for option in known_options:  # second try known paths
+                    if os.path.isdir(option):
+                        cuda_path = option
+                        break  # found cuda dir
+
+            if cuda_path is not None and os.path.isdir(cuda_path):  # if we have the cuda dir
+                cuda_v = extract_cuda_version_linux(cuda_path)
+
+        # windows and linux
+        if cuda_v is not None and cuda_path is not None:
+            # first attempt
             cudnn_v = get_cudnn_version(cudnn_path='{}/include/cudnn.h'.format(cuda_path))
 
-    elif is_linux():
-        cuda_path = get_env_variable(key='CUDA_ROOT')
-        cuda_v_file = '{}/version.txt'.format(cuda_path)
-        if os.path.exists(cuda_v_file):
-            f_obj = open(cuda_v_file, 'r')
-            for line in f_obj:
-                ls = line.strip()
-                if ls.startswith('CUDA Version'):
-                    ls_spl = ls.split(' ')
-                    if len(ls_spl) == 3:
-                        cuda_v = line.strip().split(' ')[2]
-                        break
+            # second attempt
+            if cudnn_v is None:
+                cudnn_v = get_cudnn_version(cudnn_path='{}/include/cudnn_version.h'.format(cuda_path))
+
+            # third - env variable
+            if cudnn_v is None:
+                cudnn_path = get_env_variable(key='CUDNN_FILE_PATH')
+                if cudnn_path is not None:
+                    cudnn_v = get_cudnn_version(cudnn_path=cudnn_path)
+
         if cuda_v is not None:
-            cudnn_path = '{}/include/cudnn.h'.format(cuda_path)
-            if is_jetson_nano():  # cudnn location on jetson_nano
-                cudnn_path = '/usr/include/aarch64-linux-gnu/cudnn_version_v8.h'
-            cudnn_v = get_cudnn_version(cudnn_path=cudnn_path)
+            cuda_str = '{}* CUDA Version: {}'.format(tabs * '\t', cuda_v)
+            if cudnn_v is not None:
+                cuda_str += ' (cuDNN Version {})'.format(cudnn_v)
+            else:
+                cuda_str += ' (No cuDNN found)'
+            cuda_str = add_color(cuda_str, ops=SUCCESS_C)
 
-    if cuda_v is None:
-        cuda_v = add_color('* No CUDA_PATH found', ops=FAIL_C)
-    else:
-        cuda_v = '{}* CUDA Version: {}'.format(tabs * '\t', cuda_v)
-        if cudnn_v is not None:
-            cuda_v += ' (cuDNN Version {})'.format(cudnn_v)
-        else:
-            cuda_v += ' (No cuDNN found)'
-        cuda_v = add_color(cuda_v, ops=SUCCESS_C)
+        if ack:
+            print(cuda_str)
+    except Exception:
+        pass
+    return cuda_str
 
-    if ack:
-        print(cuda_v)
-    return cuda_v
+
+def get_nvidia_gpus() -> str:
+    try:
+        cmd = 'nvidia-smi --query-gpu=gpu_name,memory.total --format=csv,noheader'
+        gpu_str_lines = run_shell_command_and_get_out(cmd=cmd, ack_cmd=False)
+        # gpu_str_lines = ['Quadro RTX 4000, 8192 Mib', 'Quadro RTX 4000, 8192 Mib']
+
+        gpu_str_all = ''
+        for i, gpu_str in enumerate(gpu_str_lines):
+            gpu_name, gpu_size = gpu_str.split(', ')
+            gpu_str_all += '[device {}] {} ({})'.format(i, gpu_name, gpu_size)
+            if i + 1 < len(gpu_str_lines):
+                gpu_str_all += ', '
+
+        gpu_str_all = add_color(f'* Nvidia GPUs: {gpu_str_all}', ops=SUCCESS_C)
+    except Exception:
+        gpu_str_all = add_color('* Nvidia GPUs: (Nvidia-smi not available)', ops=FAIL_C)
+    return gpu_str_all
 
 
 def get_env_variables(ack: bool = False, tabs: int = 1) -> dict:
@@ -419,7 +481,7 @@ def start_profiler() -> cProfile.Profile:
     return pr
 
 
-def end_profiler(pr: cProfile.Profile, rows: int = 10, ack: bool = False) -> str:
+def end_profiler(pr: cProfile.Profile, rows: int = 40, ack: bool = False) -> str:
     """
     profiling output
     :param pr: object returned from start_profiler()
@@ -440,12 +502,19 @@ def end_profiler(pr: cProfile.Profile, rows: int = 10, ack: bool = False) -> str
 
 def set_seed(seed: int = 42) -> None:
     """
-    :param seed: setting numpy and random seeds
+    :param seed: setting seed using numpy, random and torch if exists
     :return:
     see main_wrapper_test() - uses set_seed
     """
     np.random.seed(seed)
     random.seed(seed)
+    try:
+        import torch  # noqa
+        torch.manual_seed(seed)
+        torch.cuda.manual_seed(seed)
+    except (ModuleNotFoundError, Exception) as e:  # noqa
+        pass
+
     return
 
 
@@ -454,7 +523,7 @@ def version() -> str:
     :return:
     """
     # v = pkg_resources.require("wizzi_utils")[0].version
-    v = '7.1.21'
+    v = '8.0.4'
     return v
 
 
@@ -541,15 +610,6 @@ def get_system_info() -> str:
     return str(named_tuple)
 
 
-def get_wizzi_utils_root() -> str:
-    """
-    :return:
-    """
-    # project_root/misc/misc_tools.py -> remove the py and the misc folder
-    project_root = os.path.dirname(os.path.dirname(get_file_name()))
-    return project_root
-
-
 def get_py_version() -> str:
     """
     on linux there is \n and then gcc
@@ -567,6 +627,7 @@ def main_wrapper(
         seed: int = -1,
         ipv4: bool = False,
         cuda_off: bool = False,
+        nvid_gpu: bool = True,
         torch_v: bool = False,
         tf_v: bool = False,
         cv2_v: bool = False,
@@ -578,8 +639,9 @@ def main_wrapper(
     :param seed: if -1 no seed, else set_seed(seed=seed)
     :param ipv4: print computer ipv4
     :param cuda_off: make gpu invisible and force run on cpu
+    :param nvid_gpu: info on nvidia gpus. uses nvidia-smi
     :param torch_v: print torch version
-    :param tf_v: print tensorflow version
+    :param tf_v: print tensorflow lite version
     :param cv2_v: print opencv version
     :param with_pip_list: print pip list (all libraries installed)
     :param with_profiler: run profiler
@@ -630,6 +692,10 @@ def main_wrapper(
         cuda_msg += ' (Turned off)'
     print(cuda_msg)
 
+    if nvid_gpu:
+        nvidia_gpus_info = get_nvidia_gpus()
+        print(nvidia_gpus_info)
+
     if torch_v:
         try:
             from wizzi_utils.torch.torch_tools import get_torch_version
@@ -645,12 +711,6 @@ def main_wrapper(
             print(add_color('* opencv-python not Found. error: {}'.format(err), 'r'))
 
     if tf_v:
-        # try:
-        #     from wizzi_utils.tensorflow.tensorflow_tools import get_tensorflow_version
-        #     print(get_tensorflow_version(ack=False, tabs=0))
-        # except (ImportError, ModuleNotFoundError, NameError, AttributeError) as err:
-        #     print(add_color('* tensorflow not Found. error: {}'.format(err), 'r'))
-
         try:
             from wizzi_utils.tflite.tflite_tools import get_tflite_version
             print(get_tflite_version(ack=False, tabs=0))
@@ -674,7 +734,7 @@ def main_wrapper(
 
     main_function()
     if with_profiler:
-        print(end_profiler(pr))
+        print(end_profiler(pr, rows=40))
 
     print(LINES)
     print('Total run time {}'.format(get_timer_delta(start_timer)))
@@ -1284,66 +1344,6 @@ def add_color(
     return out_string
 
 
-# noinspection PyTypeChecker
-def init_logger(logger_path: str = './log.txt') -> io.TextIOWrapper:
-    """
-    :param: logger_path
-    :return: logger obj
-    see logger_test()
-    """
-    global logger
-    logger = open(file=logger_path, mode='w', encoding='utf-8')
-    return logger
-
-
-def flush_logger() -> None:
-    """
-    good for loops - writes every iteration if used
-    see logger_test()
-    """
-    global logger
-    if logger is not None:
-        logger.flush()
-    return
-
-
-def log_print(line: str, tabs: int = 0) -> None:
-    """
-    :param line:
-    :param tabs:
-    :return:
-    see logger_test()
-    """
-    global logger
-    print('{}{}'.format(tabs * '\t', line))
-    if logger is not None:
-        logger.write('{}{}\n'.format(tabs * '\t', line))
-    return
-
-
-def log_print_dict(my_dict, tabs: int = 1) -> None:
-    """
-    :param my_dict:
-    :param tabs:
-    :return:
-    see logger_test()
-    """
-    for k, v in my_dict.items():
-        log_print('{}{}: {}'.format(tabs * '\t', k, v))
-    return
-
-
-def close_logger() -> None:
-    """
-    :return:
-    see logger_test()
-    """
-    global logger
-    if logger is not None:
-        logger.close()
-    return
-
-
 def create_dir(dir_path: str, ack: bool = True, tabs: int = 1):
     """
     :param dir_path:
@@ -1428,37 +1428,54 @@ def delete_dir_with_files(dir_path: str, ack: bool = True, tabs: int = 1):
     return
 
 
-def find_files_in_folder(dir_path: str, file_suffix: str, ack: bool = False, tabs: int = 1) -> list:
+def find_files_in_folder(
+        dir_path: str,
+        file_suffix: str = '',
+        sort: bool = False,
+        ack: bool = False,
+        tabs: int = 1
+) -> list:
     """
-    :param dir_path:  root dir. will be looked in recursively
+    prune dir RECURSIVELY for files full paths
+
+    :param dir_path:  root dir.
     :param file_suffix:  e.g. '.jgp'
-    :param ack:
+        if file_suffix=='', returns all files in dir_path
+    :param sort: sort results
+        false: no sort
+        true: sort alphanumerical.
+        e.g. your files are enumerated but contain letters in the name (e.g. t1, t2, t11, t3):
+            no   sort order: t1, t11, t2, t3
+            with sort order: t1, t2, t3, t11
+        Tested (in find_files_in_folder_sorted_test()) on same format names e.g. img_x.jpg where x from i to j
+        also tested with timestamps
+
+    :param ack: prints base names of files found
     :param tabs:
     :return:
-    see find_files_in_folder_test()
-
-    sort by numbers in basename:
-    folder_path = './path' # content [1.jpg, 10.jpg 2.jpg]
-    folder_imgs=wu.find_files_in_folder(folder_path, file_suffix='.jpg', ack=True)
-    print(folder_imgs)
-    # >>> [1.jpg, 10.jpg, 2.jpg]
-    def sorter(x):
-        return int(os.path.basename(x).split('.')[0])
-    folder_imgs.sort(key=sorter)
-    print(folder_imgs)
-    # >>> [1.jpg, 2.jpg, 10.jpg]
-
-    folder_path = './path' # content [gl_1.jpg, gl_10.jpg gl_2.jpg]
-    folder_imgs=wu.find_files_in_folder(folder_path, file_suffix='.jpg', ack=True)
-    print(folder_imgs)
-    # >>> [gl_1.jpg, gl_10.jpg, gl_2.jpg]
-    def sorter(x):
-        return int(os.path.basename(x).split('.')[0][3:])
-    folder_imgs.sort(key=sorter)
-    print(folder_imgs)
-    # >>> [gl_1.jpg, gl_2.jpg, gl_10.jpg]
+    see find_files_in_folder_test() and find_files_in_folder_sorted_test()
     """
 
+    def __try_cast_to_int(string_part: str) -> (str, int):
+        try:
+            return int(string_part)
+        except ValueError:
+            return string_part
+
+    def __alphanumerical_key(file_fp: str):
+        """
+        splits string into a list of string and numbers chunks
+        e.g. file_fp='x19b': ['x', 19, 'b']
+        """
+        return [__try_cast_to_int(c) for c in re.split('(\\d+)', os.path.basename(file_fp))]
+
+    def __alphanumerical_sort(strings_list: list) -> None:
+        """
+        sorts the given list with numbers as key
+        """
+        strings_list.sort(key=__alphanumerical_key)
+        return
+
     if os.path.exists(dir_path):
         dir_path = os.path.abspath(dir_path)  # to get output of full absolute path
         all_files_found = glob.glob('{}/**/*{}'.format(dir_path, file_suffix), recursive=True)
@@ -1468,12 +1485,22 @@ def find_files_in_folder(dir_path: str, file_suffix: str, ack: bool = False, tab
             fp = fp.replace('\\', '/')  # replace windows folder \ with /
             if fp.startswith('./'):  # e.g. ./test.txt -> test.txt
                 fp = fp[2:]
-            all_files_processed.append(fp)
+            if os.path.isfile(fp):  # collect only files not dirs
+                all_files_processed.append(fp)
+
+        if sort:
+            __alphanumerical_sort(all_files_processed)
+
         if ack:
             all_files_base = [os.path.basename(fp) for fp in all_files_processed]
-            print('{}found {} files that ends with {} in folder "{}":'.format(tabs * '\t', len(all_files_processed),
-                                                                              file_suffix, dir_path))
+            if file_suffix == '':
+                msg = '{}found {} files in folder "{}":'
+                print(msg.format(tabs * '\t', len(all_files_processed), dir_path))
+            else:
+                msg = '{}found {} files that ends with {} in folder "{}":'
+                print(msg.format(tabs * '\t', len(all_files_processed), file_suffix, dir_path))
             print('{}\t{}'.format(tabs * '\t', all_files_base))
+
     else:
         all_files_processed = None
         exception_error(NOT_FOUND.format(dir_path), real_exception=False, tabs=tabs)
@@ -1927,13 +1954,6 @@ def cpu_info(one_liner: bool = False, tabs: int = 1):
     return string
 
 
-def wizzi_utils_requirements():
-    print('A snapshot of my environment packages:')
-    req_file = '../resources/wizzi_utils_requirements.txt'
-    _ = read_file_lines(fp=req_file, ack=True, tabs=0)
-    return
-
-
 def last_exception(tabs: int = 1):
     """
     prints last_exception occurred
@@ -2317,7 +2337,6 @@ def generate_requirements_file(fp_out: str, ack: bool = True) -> None:
         # out = run_shell_command_and_get_out(cmd='pip list', ack_cmd=True, ack_out=True)
         # run_shell_command(cmd="which python", ack=True)
 
-        # init_logger()
         # main_wrapper()
         out.write('# main_wrapper:\n')
         out.write('# * Run started at {}\n'.format(get_time_stamp(format_s='%d-%m-%Y %H:%M:%S')))
@@ -2346,6 +2365,10 @@ def generate_requirements_file(fp_out: str, ack: bool = True) -> None:
         cuda_msg = remove_colors(cuda_msg)
         out.write('# {}\n'.format(cuda_msg))
 
+        nvidia_gpus_info = get_nvidia_gpus()
+        nvidia_gpus_info = remove_colors(nvidia_gpus_info)
+        out.write('# {}\n'.format(nvidia_gpus_info))
+
         try:
             from wizzi_utils.open_cv.open_cv_tools import get_cv_version
             cv_v = get_cv_version(ack=False, tabs=0)
@@ -2354,6 +2377,14 @@ def generate_requirements_file(fp_out: str, ack: bool = True) -> None:
         except (ImportError, ModuleNotFoundError, NameError, AttributeError) as err:
             out.write('# * opencv-python not Found. error: {}\n'.format(err))
 
+        try:
+            from wizzi_utils.torch.torch_tools import get_torch_version
+            torch_v = get_torch_version(ack=False, tabs=0)
+            torch_v = remove_colors(torch_v)
+            out.write('# {}\n'.format(torch_v))
+        except (ImportError, ModuleNotFoundError, NameError, AttributeError) as err:
+            out.write('# * torch not Found. error: {}\n'.format(err))
+
         pkgs = get_pip_freeze_out(ack=False)
         # TODO future: remove wheel, pip, setuptools ???
         # they are missing on pip freeze and appear here
@@ -2553,7 +2584,6 @@ def read_file_lines(
         clear_r: bool = True,  # remove \r (cartridge)
         clear_t: bool = True,  # remove \t (tabs)
         ack: bool = False,
-        tabs: int = 1
 ) -> list:
     lines = []
     if os.path.exists(fp):
@@ -2573,8 +2603,9 @@ def read_file_lines(
                 lines.append(line)
             if ack:
                 for i, line in enumerate(lines):
-                    print('{}line {:3}: {}'.format(tabs * '\t', i, line))
+                    # print('{}line {:3}: {}'.format(tabs * '\t', i, line))
                     # print('\t line {}: {}'.format(i, repr(line)))
+                    print('{}'.format(line))
     else:
         exception_error(e='File {} not found'.format(os.path.abspath(fp)))
     return lines
@@ -2638,3 +2669,94 @@ def add_resource_folder_to_path(resources_dir: str) -> None:
         path_env = '{};{}'.format(path_env, os.path.abspath(resources_dir))  # add resources_dir to PATH env variable
         set_env_variable(key='PATH', val=path_env)
     return
+
+
+def get_repo_root(repo_name: str = 'repo', ack: bool = False) -> str:
+    """
+    :param repo_name:
+    :param ack:
+    :return:
+    anywhere from the project - we should have prefix/repo_name/suffix
+    return prefix/repo_name
+    prefix change on each system
+    """
+    cwd = os.getcwd()
+    if repo_name in cwd:
+        cwd_split = cwd.split(repo_name)
+        repo_root_path = os.path.join(cwd_split[0], repo_name)
+        if ack:
+            print('\tRepoRoot={}'.format(repo_root_path))
+    else:
+        exception_error('{} not found in current path'.format(repo_name))
+        repo_root_path = 'N/A'
+    return repo_root_path
+
+
+def rename_folder(dir_path: str, new_name: str, ack: bool = True) -> str:
+    """
+    renames a folder and returns the path of the new folder
+    :param dir_path: path of the target folder
+    :param new_name: new dir name
+    :param ack:
+    :return:
+    """
+    dir_path = os.path.abspath(dir_path)
+    new_name_fp = None
+    if not os.path.exists(dir_path):
+        exception_error(e='folder {} not found. can\'t rename...'.format(dir_path))
+    else:
+        new_name_fp = '{}/{}'.format(os.path.dirname(dir_path), new_name)
+        if os.path.exists(new_name_fp):
+            exception_error(e='new folder name {} exist. can\'t rename...'.format(new_name_fp))
+        else:
+            os.rename(dir_path, new_name_fp)
+            if ack:
+                files_n = len(find_files_in_folder(dir_path=new_name_fp, file_suffix=''))
+                print('\t{} renamed to {} ({} files)'.format(dir_path, new_name_fp, files_n))
+    return new_name_fp
+
+
+def download_wizzi_utils_env_snapshot(ack: bool = False):
+    """
+    snapshot of a working environment
+    """
+    try:
+        from wizzi_utils.socket.socket_tools import download_file
+        snapshot_file_path = './wizzi_utils_env_snapshot.txt'
+        if not os.path.exists(snapshot_file_path):
+            git_pref = 'https://raw.githubusercontent.com/2easy4wizzi/wizzi_utils_pypi'
+            success = download_file(
+                url=f'{git_pref}/main/resources/wizzi_utils_env_snapshot.txt',
+                dst_path=snapshot_file_path)
+            if success and ack:
+                read_file_lines(fp=snapshot_file_path, ack=True)
+        else:
+            print(f'file {os.path.abspath(snapshot_file_path)} exists')
+
+    except (ImportError, ModuleNotFoundError, NameError, AttributeError) as err:
+        print(add_color('* tflite_runtime not Found. error: {}'.format(err), 'r'))
+
+    return
+
+
+def download_wizzi_utils_requirements_txt(ack: bool = False):
+    """
+    snapshot of a working environment
+    """
+    try:
+        from wizzi_utils.socket.socket_tools import download_file
+        req_file_path = './requirements.txt'
+        if not os.path.exists(req_file_path):
+            git_pref = 'https://raw.githubusercontent.com/2easy4wizzi/wizzi_utils_pypi'
+            success = download_file(
+                url=f'{git_pref}/main/resources/requirements.txt',
+                dst_path=req_file_path)
+            if success and ack:
+                read_file_lines(fp=req_file_path, ack=True)
+        else:
+            print(f'file {os.path.abspath(req_file_path)} exists')
+
+    except (ImportError, ModuleNotFoundError, NameError, AttributeError) as err:
+        print(add_color('* tflite_runtime not Found. error: {}'.format(err), 'r'))
+
+    return
