@@ -62,14 +62,15 @@ VIDEOS_D = {  # https://www.shutterstock.com/video
 }
 
 
-def create_demo_file(path: str, tabs: int = 1) -> None:
+def create_demo_file(path: str, ack: bool = True, tabs: int = 1) -> None:
     if not os.path.exists(os.path.dirname(path)):
         mt.create_dir(os.path.dirname(path))
     f = open(path, "w")
     f.write("Now the file has more content!\n" * 1000)
     f.close()
     file_msg = '{}({})'.format(path, mt.file_or_folder_size(path))
-    print('{}{}'.format(tabs * '\t', mt.CREATED.format(file_msg)))
+    if ack:
+        print('{}{}'.format(tabs * '\t', mt.CREATED.format(file_msg)))
     return
 
 
@@ -197,12 +198,6 @@ def os_test():
     return
 
 
-def get_wizzi_utils_root_test():
-    mt.get_function_name(ack=True, tabs=0)
-    print('\t{}'.format(mt.get_wizzi_utils_root()))
-    return
-
-
 def main_wrapper_test():
     def temp_function():
         print('hello_world')
@@ -533,23 +528,6 @@ def add_color_test():
     return
 
 
-def logger_test():
-    mt.get_function_name(ack=True, tabs=0)
-    mt.create_dir(TEMP_FOLDER1)
-    path = '{}/{}_log_{}.txt'.format(TEMP_FOLDER1, JUST_A_NAME, mt.get_time_stamp(format_s='%Y_%m_%d_%H_%M_%S'))
-    mt.init_logger(logger_path=path)
-    mt.log_print(line='\tline 1')
-    mt.flush_logger()
-    mt.log_print(line='line 2', tabs=1)
-    mt.log_print(line='line 3', tabs=3)
-    mt.close_logger()
-
-    print('reading from {}'.format(path))
-    mt.read_file_lines(fp=path, ack=True)
-    mt.delete_dir_with_files(TEMP_FOLDER1)
-    return
-
-
 def create_and_delete_empty_dir_test():
     mt.get_function_name(ack=True, tabs=0)
     mt.create_dir(dir_path=TEMP_FOLDER1)
@@ -579,15 +557,53 @@ def create_and_delete_dir_with_files_test():
 
 
 def find_files_in_folder_test():
+    mt.get_function_name(ack=True, tabs=0)
     test_f = TEMP_FOLDER1
+    inner_f = '{}/inner_folder'.format(test_f)
     txt1 = '{}/{}'.format(test_f, DEMO_FILE)
     txt2 = '{}/v2_{}'.format(test_f, DEMO_FILE)
+    txt3 = '{}/{}'.format(inner_f, DEMO_FILE)  # inner file
     zip1 = '{}/{}.zip'.format(test_f, JUST_A_NAME)
     create_demo_file(txt1)
     create_demo_file(txt2)
+    create_demo_file(txt3)
     create_demo_file(zip1)
     mt.find_files_in_folder(dir_path=test_f, file_suffix='.txt', ack=True)
     mt.find_files_in_folder(dir_path=test_f, file_suffix='.zip', ack=True)
+    mt.find_files_in_folder(dir_path=test_f, ack=True)  # all files in folder
+    mt.delete_dir_with_files(test_f)
+    return
+
+
+def find_files_in_folder_sorted_test():
+    mt.get_function_name(ack=True, tabs=0)
+    test_f = TEMP_FOLDER1
+
+    print('simple numerical test:')
+    files = ['0', '32', '3', '5', '4', '31']
+    for f in files:
+        create_demo_file('{}/{}.jpg'.format(test_f, f), ack=False)
+
+    mt.find_files_in_folder(dir_path=test_f, sort=False, ack=True)
+    mt.find_files_in_folder(dir_path=test_f, sort=True, ack=True)
+    mt.delete_dir_with_files(test_f)
+
+    print('complex numerical test:')
+    for f in files:
+        create_demo_file('{}/img_{}demo.jpg'.format(test_f, f), ack=False)
+    mt.find_files_in_folder(dir_path=test_f, sort=False, ack=True)
+    mt.find_files_in_folder(dir_path=test_f, sort=True, ack=True)
+    mt.delete_dir_with_files(test_f)
+
+    print('time stamp test:')
+    for i in range(5):
+        ts = mt.get_time_stamp(format_s='%Y_%m_%d_%H_%M_%S_%f')
+        if i % 2:  # trim a digit from the end to give sorting something to do (else sort and no sort - same result)
+            ts = ts[:-1]
+        create_demo_file('{}/img_{}.jpg'.format(test_f, ts), ack=False)
+
+    mt.find_files_in_folder(dir_path=test_f, sort=False, ack=True)
+    mt.find_files_in_folder(dir_path=test_f, sort=True, ack=True)
     mt.delete_dir_with_files(test_f)
     return
 
@@ -902,18 +918,17 @@ def get_linkable_exception_test():
     return
 
 
-def generate_requirements_file_test():
+def generate_requirements_file_test(real_req: bool = False):
     mt.get_function_name_and_line(ack=True, tabs=0)
-    fp = '{}/requirements.txt'.format(PLAY_GROUND)
+    if real_req:  # for saving a snapshot for the users
+        test_misc_file = mt.get_file_name(depth=1)
+        test_misc_dir = os.path.dirname(test_misc_file)
+        main_src_dir = '{}/../../'.format(test_misc_dir)
+        fp = os.path.abspath('{}/wizzi_utils_requirements.txt'.format(main_src_dir))
+    else:
+        fp = '{}/requirements.txt'.format(PLAY_GROUND)
     mt.generate_requirements_file(fp_out=fp)
-    # file1 = open(fp, 'r')
-    # lines = file1.readlines()
-    # file1.close()
-    # print('\nfile content:')
-    # for i, line in enumerate(lines):
-    #     print("\t{}".format(line.rstrip()))
-    # mt.delete_file(fp)
-    _ = mt.read_file_lines(fp=fp, ack=True, tabs=0)
+    _ = mt.read_file_lines(fp=fp, ack=True)
     return
 
 
@@ -1032,6 +1047,7 @@ def read_file_lines_test():
 
 
 def get_path_file_system_info_test():
+    mt.get_function_name_and_line(ack=True, tabs=0)
     _, _, _, _ = mt.get_path_file_system_info(path=PLAY_GROUND, ack=True)
     if mt.is_windows():
         if os.path.exists('C:\\Windows\\System32'):
@@ -1043,6 +1059,27 @@ def get_path_file_system_info_test():
     return
 
 
+def get_repo_root_test():
+    mt.get_function_name_and_line(ack=True, tabs=0)
+    ret = mt.get_repo_root(repo_name='wizzi_utils_pypi', ack=True)  # will return 'N/A' outside wizzi utils repo
+    print('\t{}'.format(ret))
+    return
+
+
+def rename_folder_test():
+    mt.get_function_name_and_line(ack=True, tabs=0)
+
+    _ = mt.rename_folder(dir_path='./NoSuchDir', new_name='NoSuchDir2')  # expected exception
+
+    dir_path = '{}/NewDir'.format(PLAY_GROUND)
+    mt.create_dir(dir_path=dir_path)
+    create_demo_file(path='{}/dm.txt'.format(dir_path))
+    _ = mt.rename_folder(dir_path=dir_path, new_name='NewDir')  # expected exception
+    new_dir_fp = mt.rename_folder(dir_path=dir_path, new_name='NewDir2')  # expect success
+    mt.delete_dir_with_files(dir_path=new_dir_fp)
+    return
+
+
 def test_all():
     print('{}{}:'.format('-' * 5, mt.get_base_file_and_function_name(depth=1)))
     try_say_welcome()
@@ -1058,7 +1095,6 @@ def test_all():
     make_cuda_invisible_test()
     profiler_test()
     os_test()
-    get_wizzi_utils_root_test()
     main_wrapper_test()
     to_str_test()
     save_load_np_test()
@@ -1081,12 +1117,12 @@ def test_all():
     get_function_name_and_line_test()
     get_base_file_and_function_name_test()
     add_color_test()
-    logger_test()
     create_and_delete_empty_dir_test()
     create_and_delete_dir_with_files_test()
     move_file_test()
     copy_file_test()
     find_files_in_folder_test()
+    find_files_in_folder_sorted_test()
     delete_file_test()
     delete_files_test()
     sleep_test()
@@ -1118,5 +1154,7 @@ def test_all():
     has_admin_test()
     read_file_lines_test()
     get_path_file_system_info_test()
+    get_repo_root_test()
+    rename_folder_test()
     print('{}'.format('-' * 20))
     return
