@@ -245,19 +245,19 @@ class OdBaseModel(BaseModel):
 
             # DRAW BBOX
             k = '{}_bbox'.format(label)  # check custom color for this class
-            color_bgr = pyplt.get_BGR_color(colors_d[k]) if k in colors_d else pyplt.get_BGR_color(
+            color_bgr = pyplt.get_bgr_color(colors_d[k]) if k in colors_d else pyplt.get_bgr_color(
                 colors_d['default_bbox'])
             cv2.rectangle(img=cv_img, pt1=(x0, y0), pt2=(x1, y1), color=color_bgr, thickness=2)
 
             if draw_tl_image:  # DRAW TL
                 for loc, point_and_color in traffic_light_d.items():
                     cv2.circle(cv_img, center=tuple(point_and_color['point']), radius=3,
-                               color=pyplt.get_BGR_color(point_and_color['color']), thickness=-1)
+                               color=pyplt.get_bgr_color(point_and_color['color']), thickness=-1)
 
             if draw_sub_image and bbox_sub_image_d is not None:  # DRAW sub image
                 pt1 = (bbox_sub_image_d['x0'], bbox_sub_image_d['y0'])
                 pt2 = (bbox_sub_image_d['x1'], bbox_sub_image_d['y1'])
-                cv2.rectangle(img=cv_img, pt1=pt1, pt2=pt2, color=pyplt.get_BGR_color(colors_d['sub_image']),
+                cv2.rectangle(img=cv_img, pt1=pt1, pt2=pt2, color=pyplt.get_bgr_color(colors_d['sub_image']),
                               thickness=1)  # sub image
 
             if draw_labels:
@@ -442,8 +442,8 @@ class PdBaseModel(BaseModel):
         self.joint_names = self.model_cfg['joint_names']
         self.pairs_indices = self.model_cfg['pairs_indices']
         # grab default colors and convert to bgr
-        self.pairs_indices_colors = [pyplt.get_BGR_color(c) for c in self.model_cfg['pairs_indices_colors']]
-        self.joint_colors = [pyplt.get_BGR_color(c) for c in self.model_cfg['joint_colors']]
+        self.pairs_indices_colors = [pyplt.get_bgr_color(c) for c in self.model_cfg['pairs_indices_colors']]
+        self.joint_colors = [pyplt.get_bgr_color(c) for c in self.model_cfg['joint_colors']]
         self.allowed_joint_names = list(
             self.joint_names.values()) if allowed_joint_names is None else allowed_joint_names
         self.min_p_valid_joints = min_p_valid_joints
@@ -549,13 +549,13 @@ class PdBaseModel(BaseModel):
             bbox_sub_image_d = detection['bbox_sub_image'] if 'bbox_sub_image' in detection else None
 
             if draw_bbox:  # DRAW BBOX
-                color_bgr = pyplt.get_BGR_color(colors_d['bbox_c'])
+                color_bgr = pyplt.get_bgr_color(colors_d['bbox_c'])
                 pt1 = (pose_bbox['x0'], pose_bbox['y0'])
                 pt2 = (pose_bbox['x1'], pose_bbox['y1'])
                 cv2.rectangle(img=cv_img, pt1=pt1, pt2=pt2, color=color_bgr, thickness=2)
 
             if draw_sub_image and bbox_sub_image_d is not None:  # DRAW sub image
-                color_bgr = pyplt.get_BGR_color(colors_d['sub_image_c'])
+                color_bgr = pyplt.get_bgr_color(colors_d['sub_image_c'])
                 pt1 = (bbox_sub_image_d['x0'], bbox_sub_image_d['y0'])
                 pt2 = (bbox_sub_image_d['x1'], bbox_sub_image_d['y1'])
                 cv2.rectangle(img=cv_img, pt1=pt1, pt2=pt2, color=color_bgr, thickness=1)  # sub image
@@ -565,9 +565,9 @@ class PdBaseModel(BaseModel):
                 if 'edge_c' in colors_d:
                     edges_colors = colors_d['edge_c']
                     if mt.is_str(edges_colors):  # 1 color for all
-                        edges_colors = [pyplt.get_BGR_color(edges_colors)] * len(self.pairs_indices)
+                        edges_colors = [pyplt.get_bgr_color(edges_colors)] * len(self.pairs_indices)
                     else:  # list of colors - must be in len(self.joint_names)
-                        edges_colors = [pyplt.get_BGR_color(c) for c in edges_colors]
+                        edges_colors = [pyplt.get_bgr_color(c) for c in edges_colors]
                 else:  # take default colors
                     edges_colors = self.pairs_indices_colors
                 for pair, bgr_c in zip(self.pairs_indices, edges_colors):
@@ -581,9 +581,9 @@ class PdBaseModel(BaseModel):
                 if 'joint_colors' in colors_d:
                     joints_colors = colors_d['joint_colors']
                     if mt.is_str(joints_colors):  # 1 color for all
-                        joints_colors = [pyplt.get_BGR_color(joints_colors)] * len(self.joint_names)
+                        joints_colors = [pyplt.get_bgr_color(joints_colors)] * len(self.joint_names)
                     else:  # list of colors - must be in len(self.joint_names)
-                        joints_colors = [pyplt.get_BGR_color(c) for c in joints_colors]
+                        joints_colors = [pyplt.get_bgr_color(c) for c in joints_colors]
                 else:  # take default colors
                     joints_colors = self.joint_colors
 
