@@ -23,8 +23,8 @@ VID_X_FRAMES_TFL = 20
 # object detection
 WITH_TF = True
 OD_OP = 1
-OD_IM_TEST = False
-OD_CAM_TEST = True
+OD_IM_TEST = True
+OD_CAM_TEST = False
 OD_VID_TEST = False
 
 # pose detection
