@@ -18,7 +18,7 @@ def tr_run(
 ):
     fps.start()
     detections = model.track_frame(cv_img, ack=DEBUG_DETECTIONS, tabs=0, frame_idx=frame_idx)
-    fps.update(ack_progress=True, tabs=1, with_title=True)
+    fps.update(ack_progress=False, tabs=1, with_title=True)
 
     model.draw_detections(
         detections,
