@@ -687,7 +687,7 @@ def get_frames_from_cap_cv2(cap: cv2.VideoCapture) -> int:
     """
     video_total_frames = None
     if cap.isOpened():
-        video_total_frames = int(cap.get(cv2.CAP_PROP_FRAME_COUNT)) - 1
+        video_total_frames = int(cap.get(cv2.CAP_PROP_FRAME_COUNT))
     return video_total_frames
 
 
@@ -696,7 +696,7 @@ def get_frames_from_cap_imutils(cap) -> int:
     :param cap:
     :return:
     """
-    video_total_frames = int(cap.stream.get(cv2.CAP_PROP_FRAME_COUNT)) - 1
+    video_total_frames = int(cap.stream.get(cv2.CAP_PROP_FRAME_COUNT))
     return video_total_frames
 
 
@@ -1182,7 +1182,8 @@ def get_roi_2dpoints(cv_img: np.array, resize: float = None, mark_color: str = '
 
 
 def get_named_roi_2dpoints(cv_img: np.array, names_colors: dict, resize: float = None,
-                           add_center_text: bool = False, cursor_arrow: bool = False) -> dict:
+                           add_center_text: bool = False, cursor_arrow: bool = False,
+                           loc: str = 'tl') -> dict:
     """
     :param cv_img: gray\bgr
     :param names_colors: dict of name to color (str, str) - recommended ordered dict
@@ -1191,6 +1192,7 @@ def get_named_roi_2dpoints(cv_img: np.array, names_colors: dict, resize: float =
     :param resize: float in (0,1] - if none: no resize. else enlarge\reduce to 'resize'%
     :param add_center_text: add 2d value above X mark
     :param cursor_arrow: if True and is_windows(), changes cursor to arrow style making it easier to select roi
+    :param loc: 'tl' 'bl' 'tr' 'br' for top or bottom left or right, else None
     :return: named_points. e.g. {'port1_top_left': (100,100), ... }
     notice if you press 'q' and didn't mark all the points, you'll get some of the points
     """
@@ -1205,6 +1207,7 @@ def get_named_roi_2dpoints(cv_img: np.array, names_colors: dict, resize: float =
     if len(cv_img_clean.shape) == 2:  # gray - convert to 3 channel gray
         cv_img_clean = gray_to_bgr(cv_img_clean)
     cv_img_temp = cv_img_clean.copy()  # clone not to draw on original image
+    x_offset = 200 if loc in ['tr', 'br'] else 0
 
     # noinspection PyUnusedLocal
     def get_roi_xy(event, x, y, flags, param):
@@ -1233,17 +1236,14 @@ def get_named_roi_2dpoints(cv_img: np.array, names_colors: dict, resize: float =
                     'xy': xy
                 }
                 current_idx += 1
-                if current_idx < len(colors):
-                    draw_next_info(cv_img_temp, _name=names[current_idx], _color=colors[current_idx])
-        return
-
-    def draw_next_info(_cv_img: np.array, _name: str, _color: str) -> None:
-        h = cv_img.shape[0]
-        # draw a black rectangle
-        cv2.rectangle(_cv_img, pt1=(5, h - 25), pt2=(250, h - 5), color=pyplt.get_bgr_color('black'), thickness=-1)
-        text_color = 'g' if _color in ['black', 'k'] else _color  # rect is black so don't allow black text color
-        # add info text on the rect
-        add_text(_cv_img, header='{}: {}'.format(_name, _color), pos=(5, h - 9), text_color=text_color, with_rect=False)
+                if current_idx < len(colors) and loc is not None:
+                    add_header(
+                        cv_img_temp,
+                        header='{}: {}'.format(names[current_idx], colors[current_idx]),
+                        loc=loc,
+                        text_color=colors[current_idx],
+                        with_rect=True
+                    )
         return
 
     title = "select_roi:img shape {}('d' to delete last,'q' to finish). names={}, colors={}".format(cv_img_temp.shape,
@@ -1251,7 +1251,15 @@ def get_named_roi_2dpoints(cv_img: np.array, names_colors: dict, resize: float =
 
     cv2.namedWindow(title)
     cv2.setMouseCallback(title, get_roi_xy)
-    draw_next_info(cv_img_temp, _name=names[current_idx], _color=colors[current_idx])
+    if loc is not None:
+        add_header(
+            cv_img_temp,
+            header='{}: {}'.format(names[current_idx], colors[current_idx]),
+            loc=loc,
+            text_color=colors[current_idx],
+            with_rect=True,
+            x_offset=x_offset
+        )
 
     for i in range(10 ** 10):
         k = display_open_cv_image(cv_img_temp, title=title, ms=1, loc='tl', resize=resize)
@@ -1262,7 +1270,14 @@ def get_named_roi_2dpoints(cv_img: np.array, names_colors: dict, resize: float =
                 last_name = names[last_idx]
                 del named_points[last_name]
                 current_idx -= 1  # set the pointer one back
-                draw_next_info(cv_img_temp, _name=names[current_idx], _color=colors[current_idx])
+                if loc is not None:
+                    add_header(
+                        cv_img_temp,
+                        header='{}: {}'.format(names[current_idx], colors[current_idx]),
+                        loc=loc,
+                        text_color=colors[current_idx],
+                        with_rect=True
+                    )
                 for name, c_xy_dict in named_points.items():  # draw the the remaining colors
                     c, d2p = c_xy_dict['c'], c_xy_dict['xy']
                     draw_x(cv_img_temp, x_center_xy=d2p, x_color=c, pixels=20,
