@@ -8,6 +8,10 @@ import os
 from collections import OrderedDict
 # noinspection PyPackageRequirements
 import cv2
+import ssl
+
+# noinspection PyProtectedMember
+ssl._create_default_https_context = ssl._create_unverified_context
 
 LOOP_TESTS = 50
 BLOCK_MS_NORMAL = 2000  # 0 to block
@@ -580,7 +584,15 @@ def video_creator_mp4_test():
 
 def video_creator_size_test():
     wu.get_function_name(ack=True, tabs=0)
-    wu.add_resource_folder_to_path(resources_dir='../resources')
+
+    # NOTICE MKV FIX ON WINDOWS on python 3.8
+    # download the file below to any dir. let DIR be its path. set env var MKV_DLL_DIR=DIR
+    # https://github.com/2easy4wizzi/wizzi_utils_pypi/raw/main/resources/openh264-1.8.0-win64.dll
+    MKV_DLL_DIR = wu.get_env_variable(key='MKV_DLL_DIR')
+    if MKV_DLL_DIR is not None and os.path.isdir(MKV_DLL_DIR) and wu.is_windows():
+        # adding this folder - contains dll for h264 for python 3.8
+        wu.add_resource_folder_to_path(resources_dir=MKV_DLL_DIR)
+
     # now open video file
     vid_name = mtt.DOG1
     video_path = get_vid_from_web(name=vid_name)
@@ -680,8 +692,14 @@ def cuda_on_gpu_test():
             * PY_PATH/Scripts # for pip...
             * PY_PATH/libs  # for python36.lib file
             * PY_PATH/include # h files
+        e.g. added to path system variable:
+            C:/Users/GiladEiniKbyLake/.conda/envs/py385cvCuda
+            C:/Users/GiladEiniKbyLake/.conda/envs/py385cvCuda/Scripts
+            C:/Users/GiladEiniKbyLake/.conda/envs/py385cvCuda/include
+            C:/Users/GiladEiniKbyLake/.conda/envs/py385cvCuda/libs
     2b pip install numpy (if you want tf, 1.19.5)
     3 open CMake gui
+    * first delete cache (file > delete cache)
     * source code: location of openCV source
     * create 2 new dirs in the level of openCV source called build and install
     * where to build: location of build folder created above
@@ -942,8 +960,11 @@ def get_named_roi_2dpoints_test():
 
     names_colors = OrderedDict([('port1_g', 'g'), ('port1_r', 'r'), ('port1_b', 'b')])
 
-    colors_points = cvt.get_named_roi_2dpoints(cv_img, names_colors=names_colors, resize=1.6,
-                                               add_center_text=True, cursor_arrow=True)  # enlarge to 160%
+    colors_points = cvt.get_named_roi_2dpoints(
+        cv_img, names_colors=names_colors, resize=1.6,
+        add_center_text=True, cursor_arrow=True,
+        loc='tl'
+    )  # enlarge to 160%
     print(wu.to_str(colors_points, '\tcolors_points selected'))
     # cvt.display_open_cv_image(cv_img, title='x', ms=0, loc='tl', resize=None)  # check image not corrupted
     return
