@@ -1,6 +1,3 @@
-"""
-:sub_package: json
-"""
 try:
     from wizzi_utils.socket.test.test_socket_tools import *
 except ModuleNotFoundError as e:
