@@ -81,7 +81,7 @@ def is_trainable(var: torch.Tensor) -> bool:
 def set_trainable(var: torch.Tensor, trainable: bool = True) -> None:
     """
     :param var:
-    :param trainable: True\False
+    :param trainable: True/False
     sets the var to 'trainable'
     """
     var.requires_grad = trainable
@@ -91,7 +91,7 @@ def set_trainable(var: torch.Tensor, trainable: bool = True) -> None:
 def is_cuda(var: torch.Tensor) -> bool:
     """
     :param var:
-    :return: if the variable is Cuda\CPU variable
+    :return: if the variable is Cuda/CPU variable
     see is_cuda_test()
     """
     # noinspection PyTypeChecker
@@ -176,7 +176,7 @@ def to_str(var: any,
     :param fp: float_precision: round number if possible(float, list or np array of floats...)
             fp>0 round
             fp==None: no rounding
-    :param wm: with_meta: with meta data such as type, len\shape, dtype...
+    :param wm: with_meta: with metadata such as type, len/shape, dtype...
     :param rec: recursive: to keep printing if there are more items inside e.g. np.array(shape=(2,3,4)) -> 3 prints
     :return: informative string of the variable
     see to_str_test() on test_torch_tools.py
@@ -263,6 +263,7 @@ def torch_uniform(shape: tuple, range_low: float, range_high: float) -> torch.Te
     :return:
     see torch_uniform_test()
     """
+    # noinspection PyArgumentList
     ret = torch.empty(shape).uniform_(range_low, range_high)
     return ret
 
